import styled from "styled-components";
import Link from "next/link";
import React from "react";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";

interface SnarveiProps {
    lenke: string;
    tekst: string;
    ikonPath: string;
}

export const LenkeKort = ({ lenke, tekst, ikonPath }: SnarveiProps) => (
    <StyledLi>
        <Link href={lenke} passHref legacyBehavior>
            <Kortlenke href={lenke}>
                <Ikon path={ikonPath} />
                <Heading as="h2" styleLevel="4">
                    {tekst}
                </Heading>
            </Kortlenke>
        </Link>
    </StyledLi>
);

const StyledLi = styled.li`
    box-sizing: border-box;
    min-width: 17.5rem;
    width: max-content;
`;

export const Kortlenke = styled.a`
    flex-direction: row;
    gap: 16px;
    padding: 24px 24px;
    background-color: var(--white);
    border-bottom: 2px solid var(--orange);
    box-shadow: 0 0 6px 2px rgba(63, 62, 67, 0.08);
    box-sizing: border-box;
    color: inherit;
    display: flex;
    height: 100%;
    text-decoration: none;

    :hover,
    :focus {
        box-shadow: 0 0 8px 4px rgba(53, 62, 67, 0.2);
        padding: 22px 22px 24px 22px;
    }

    :hover {
        border-width: 3px;
        margin-bottom: -1px;

        h2 {
            border-bottom: 2px solid var(--gray-dark-65);
            margin-bottom: -2px;
            width: max-content;
        }
    }

    :focus {
        border: 2px solid var(--gray-dark);
        outline: 2px solid var(--orange);
        outline-offset: 2px;
        padding: 22px 30px 24px 30px;
    }
`;

interface IkonProps {
    path: string;
}

const Ikon = styled.i<IkonProps>`
    background: url(${(props) => props.path}) no-repeat;
    width: 38px;
    height: 26px;
    display: block;
`;
