import { ApiRespons, FeilType, fetcher, FetchStatus, ikkeRevalidate } from "../../api/api";
import { useSetAtom } from "jotai/index";
import { GCP_MEDIATOR_URL } from "../../utils/baseUrl";
import useSWR from "swr";
import { useEffect } from "react";
import { aggregertFriksjonsAtom, friksjonsanalyseMetadataAtom } from "./apiAtoms";

export interface FriksjonBeregningDto {
    metadata: FriksjonBeregningMetadataDto[];
    friksjonsdata: FriksjonBeregningMålingerDto[];
}
export interface FriksjonBeregningMetadataDto {
    øktid: number;
    kontraktId: number;
    fylke: string;
    kommune: string;
    vegkategori: string;
    startDato: string;
    sluttDato: string;
    antallMålinger: number;
    totalDistanse: number;
    spor: string;
    veg: string;
    delstrekning: string;
    vegsystemreferanse: string;
}

export interface FriksjonBeregningMålingerDto {
    timestamp: string;
    usikker: boolean;
    friksjon: Friksjon[];
}

export interface Friksjon {
    spor: string; // I, Y, M
    friksjon: number;
}

export const useHentFriksjonsanalyser = () => {
    const setFriksjon = useSetAtom(aggregertFriksjonsAtom);
    const setMetadata = useSetAtom(friksjonsanalyseMetadataAtom);
    const key = `${GCP_MEDIATOR_URL}/friksjonsanalyse`;
    const { data, isLoading } = useSWR<ApiRespons<FriksjonBeregningDto>>(
        key,
        customFetcher,
        ikkeRevalidate,
    );

    useEffect(() => {
        if (isLoading) {
            setFriksjon({ status: FetchStatus.Laster });
            return;
        }

        data && setFriksjon(data);
        if (data?.suksess) {
            setMetadata(data.data.metadata);
        }
    }, [data, isLoading]);
};

async function customFetcher(url: string): Promise<ApiRespons<FriksjonBeregningDto>> {
    const response = await fetcher<FriksjonBeregningDto>(url, FeilType.UKJENT_FEIL);
    return response;
}
