"use client";
import { useAtomValue } from "jotai";
import { useHentFriksjonsanalyser } from "../api/useHentFriksjonsanalyser";
import { friksjonsanalyseMetadataAtom } from "../api/apiAtoms";
import { AnalyseSideHeader } from "../components/analyseSideHeader";
import ErrorBoundary from "../../components/feil/ErrorBoundary";
import { AuthenticationWrapper } from "../../components/AuthenticationWrapper";
import styled from "styled-components";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import BarPlot from "./BarPlot";
import { StackedBarplot } from "./StackedBarplot";

export const FriksjonSide = () => {
    const metadata = useAtomValue(friksjonsanalyseMetadataAtom);
    useHentFriksjonsanalyser();

    return (
        <ErrorBoundary info={`side: Analyseportal friksjon`}>
            <AuthenticationWrapper>
                <AnalyseSideHeader side={"friksjon"} />
                <Sideinnhold>
                    <AnalyseContainer>
                        <Tekst størrelse={"M"} noMargin={true}>
                            Her viser vi data fra friksjonsmålinger. Info om diverse.
                        </Tekst>
                    </AnalyseContainer>
                    <FilterContainer>
                        <Tekst>
                            Filtermeny linje her, med dato fra-til, område, type veg, osv. Og valg
                            på å hente alle data
                        </Tekst>
                    </FilterContainer>
                    <AnalyseContainer>
                        <Heading as={"h2"} styleLevel={"2"}>
                            Metadata
                        </Heading>
                        <BarPlot metadata={metadata} />
                        <Heading as={"h2"} styleLevel={"2"}>
                            Friksjonsdata
                        </Heading>
                        <StackedBarplot />
                    </AnalyseContainer>
                </Sideinnhold>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Sideinnhold = styled.main`
    display: flex;
    flex-direction: column;
    gap: 2rem;
`;

const FilterContainer = styled.div`
    padding: 1rem;
    display: flex;
    flex-direction: row;
    gap: 2rem;
    background-color: var(--gray-light);
`;

const AnalyseContainer = styled.div`
    padding: 1rem;
    display: flex;
    flex-direction: column;
    gap: 1rem;
`;

export default FriksjonSide;
