import {
    Bar,
    BarChart,
    CartesianGrid,
    Label,
    ResponsiveContainer,
    Tooltip,
    XAxis,
    YAxis,
} from "recharts";
import styled from "styled-components";
import { breakpointNettbrett } from "../../utils/constants";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import { ColumnWrapper } from "../../components/fellesKomponenter/wrappers/wrappers";
import { FriksjonsGrupperLegend } from "./FriksjonsGrupperLegend";

export const StackedBarplot = () => {
    const dataAgg = [
        {
            fylke: "Vestfold",
            god: 60, //over 0.3
            middels: 25, //0.25-0.3
            dårlig: 10, //0.2 - 0.25
            ille: 5, //under 0.2
        },
        {
            fylke: "Telemark",
            god: 40, //over 0.3
            middels: 30, //0.25-0.3
            dårlig: 20, //0.2 - 0.25
            ille: 10, //under 0.2
        },
        {
            fylke: "Troms",
            god: 60, //over 0.3
            middels: 25, //0.25-0.3
            dårlig: 10, //0.2 - 0.25
            ille: 5, //under 0.2
        },
        {
            fylke: "Trøndelag",
            god: 60, //over 0.3
            middels: 25, //0.25-0.3
            dårlig: 10, //0.2 - 0.25
            ille: 5, //under 0.2
        },
    ];

    const customLegend = <FriksjonsGrupperLegend />;

    return (
        <div>
            <GrafContainer>
                <CustomHeading styleLevel={"4"} as={"h4"}>
                    Prosentvis fordeling av friksjon
                </CustomHeading>
                <RowContainer>
                    <ColumnWrapper>
                        <Heading as={"h5"} styleLevel={"5"}>
                            Friksjon per fylke
                        </Heading>
                        {customLegend}
                        <ResponsiveContainer height={360} minWidth={550}>
                            <BarChart
                                margin={{ top: 60, right: 30, left: 30, bottom: 30 }}
                                data={dataAgg}
                                barSize={30}
                            >
                                <CartesianGrid strokeDasharray="3 3" />
                                <XAxis dataKey="fylke" tick={{ fontSize: 16 }}>
                                    <Label
                                        value={"Fylke"}
                                        offset={-15}
                                        position="insideBottom"
                                        fontSize={20}
                                    />
                                </XAxis>
                                <YAxis tick={{ fontSize: 16 }}>
                                    <Label
                                        value={"Prosent"}
                                        offset={15}
                                        position="insideBottomLeft"
                                        angle={-90}
                                        fontSize={20}
                                    />
                                </YAxis>

                                <Tooltip />
                                <Bar
                                    dataKey="ille"
                                    fill={StackedGrafFargekoder.ILLE}
                                    stackId={"a"}
                                />
                                <Bar
                                    dataKey="dårlig"
                                    fill={StackedGrafFargekoder.DÅRLIG}
                                    stackId={"a"}
                                />
                                <Bar
                                    dataKey="middels"
                                    fill={StackedGrafFargekoder.MIDDELS}
                                    stackId={"a"}
                                />
                                <Bar dataKey="god" fill={StackedGrafFargekoder.GOD} stackId={"a"} />
                            </BarChart>
                        </ResponsiveContainer>
                    </ColumnWrapper>
                </RowContainer>
            </GrafContainer>
        </div>
    );
};

const GrafContainer = styled.div`
    @media (max-width: ${breakpointNettbrett}) {
        overflow-x: scroll;
        overflow-y: hidden;
    }
`;

export enum StackedGrafFargekoder {
    GOD = "#6bab06",
    MIDDELS = "#ffdc00",
    DÅRLIG = "#d74a11",
    ILLE = "#800006",
}

const CustomHeading = styled(Heading)`
    display: flex;
    justify-content: center;
    margin-bottom: 10px;
`;

const RowContainer = styled.div`
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
`;

export default StackedBarplot;
