import { finnMiljø, Miljø } from "../../utils/miljø";
import { DRIFTSPORTAL_API_URL } from "../../utils/baseUrl";

export enum LoggNivå {
    Debug = "debug",
    Info = "info",
    Warn = "warn",
    Error = "error",
}

type LoggInfo =
    | {
          loggNivå: LoggNivå.Error;
          loggMelding?: string;
          error: Error;
      }
    | {
          loggNivå: LoggNivå.Debug | LoggNivå.Info | LoggNivå.Warn;
          loggMelding: string;
          error?: Error;
      };
export const loggFrontend = async function loggFrontend(logginfo: LoggInfo) {
    if (finnMiljø() === Miljø.lokal || finnMiljø() === Miljø.mobil) {
        return;
    }
    const body = JSON.stringify({
        loggMelding: logginfo.loggMelding,
        feilmeldingNavn: `${logginfo.error?.name}`,
        feilmelding: `${logginfo.error?.message}`,
    });
    try {
        const res = await fetch(`${DRIFTSPORTAL_API_URL}/logging/${logginfo.loggNivå}`, {
            method: "POST",
            body,
            headers: {
                "content-type": "application/json",
            },
            credentials: "include",
        });
        if (!res.ok) {
            console.error(`${res.status}-feil ved logging av:\n ${body}`);
        }
    } catch (error) {
        console.error(`Ukjent feil ved logging av:\n ${body}`);
    }
};
