import useSWR from "swr";
import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "./api";
import { GCP_MEDIATOR_URL } from "../utils/baseUrl";
import dayjs, { Dayjs } from "dayjs";
import { epochTilEnkelTimestamp, tilEnkelTimestampStr } from "../utils/tid";

export interface VærdataDto {
    målestasjonId?: string;
    tidspunkt?: string;
    luftfuktighet?: number;
    vegbanetemperatur?: number;
    vindHastighet?: number;
    vindHastighetMax?: number;
    vindRetning?: number;
    temperatur?: number;
    duggpunktTemperatur?: number;
    nedbør?: number;
    friksjon?: number;
    sikt?: number;
}

export interface Værdata {
    målestasjonId?: string;
    værtidspunkt?: string;
    luftfuktighet?: number;
    vegbanetemperatur?: number;
    vindHastighet?: number;
    vindHastighetMax?: number;
    vindRetning?: number;
    temperatur?: number;
    duggpunktTemperatur?: number;
    nedbør?: number;
    friksjon?: number;
    sikt?: number;
}

export function useHentVærdata(
    tidspunkt: Dayjs,
    målestasjonId: string | undefined,
    skalHenteData: boolean = true,
): ApiRespons<VærdataDto[]> | undefined {
    const customFetcher = async (): Promise<ApiRespons<VærdataDto[]>> =>
        await fetcher<VærdataDto[]>(
            `${GCP_MEDIATOR_URL}/værdata?tidspunkt=${tilEnkelTimestampStr(
                tidspunkt,
            )}&maalestasjonId=${målestasjonId}`,
            FeilType.KUNNE_IKKE_HENTE_VÆRDATA,
        );

    const { data } = useSWR<ApiRespons<VærdataDto[]>>(
        skalHenteData ? `værdata${tilEnkelTimestampStr(tidspunkt)}${målestasjonId}` : null,
        customFetcher,
        ikkeRevalidate,
    );

    return data;
}

export const værdataDtoTilVærdata = (værdataDto: VærdataDto[]): Værdata | undefined => {
    if (værdataDto.length === 0) return undefined;
    return {
        målestasjonId: værdataDto[0].målestasjonId,
        værtidspunkt: værdataDto[0].tidspunkt
            ? dayjs(epochTilEnkelTimestamp(Number(værdataDto[0].tidspunkt))).toString()
            : "",
        luftfuktighet: værdataDto[0].luftfuktighet,
        vegbanetemperatur: værdataDto[0].vegbanetemperatur,
        vindHastighet: værdataDto[0].vindHastighet,
        vindHastighetMax: værdataDto[0].vindHastighetMax,
        vindRetning: værdataDto[0].vindRetning,
        temperatur: værdataDto[0].temperatur,
        duggpunktTemperatur: værdataDto[0].duggpunktTemperatur,
        nedbør: værdataDto[0].nedbør,
        friksjon: værdataDto[0].friksjon,
        sikt: værdataDto[0].sikt,
    };
};
