"use client";
import { EksterntLenkeKort } from "./navigasjon/EksterntLenkeKort";
import { Panel } from "../components/fellesKomponenter/Panel";
import styled from "styled-components";
import { Karusell } from "./Karusell";
import portalLenker from "./tekst/portal-lenker.json";
import tipsOgTriks from "./tekst/tips-og-triks.json";
import { OmKos } from "./OmKos";
import { TipsOgTriks } from "./TipsOgTriks";
import { InterntLenkeKort } from "./navigasjon/InterntLenkeKort";
import React, { useEffect, useRef } from "react";
import { ScrollToLenker } from "./ScrollToLenker";
import { DriftsportalHeader } from "./DriftsportalHeader";
import { UlRef } from "../utils/scrollTo";
import { sideInfo } from "../sider";
import { AuthenticationWrapper } from "../components/AuthenticationWrapper";
import { Heading } from "../components/fellesKomponenter/typografi/Heading";
import ErrorBoundary from "../components/feil/ErrorBoundary";
import { breakpointNettbrett } from "../utils/constants";
import { favorittLenkerAtom } from "./jotai/atoms";
import { useAtom } from "jotai";
import {
    FrontendLoggEvent,
    loggEventMedTabellnavnOgVerdi,
    loggFrontendEvent,
    loggNettbrett,
    loggSkjermstørrelse,
    Sider,
    TabellNavn,
} from "../utils/loggFrontend";

export const DriftsportalSide = () => {
    const [favorittLenker, settFavorittLenker] = useAtom(favorittLenkerAtom);
    const lenkerRef = useRef<HTMLUListElement>(null);
    const favorittLenkerRef = useRef<HTMLUListElement>(null);
    const tipsOgTriksRef = useRef<HTMLDivElement>(null);
    const omKosRef = useRef<HTMLDivElement>(null);
    useEffect(() => {
        loggFrontendEvent(FrontendLoggEvent.driftsportalInnlasting);
        loggSkjermstørrelse(window, Sider.driftsportal);
        loggNettbrett(Sider.driftsportal);
    }, []);

    const lenker = [
        {
            href: "#lenker",
            ref: lenkerRef,
            tekst: "Lenker",
        },
        {
            href: "#favorittLenker",
            ref: favorittLenkerRef,
            tekst: "Favoritter",
        },
        {
            href: "#tips-og-triks",
            ref: tipsOgTriksRef,
            tekst: "Tips & triks",
        },
        {
            href: "#om-kos",
            ref: omKosRef,
            tekst: "Litt om KOS",
        },
    ];

    const håndterFavorittLenkeKlikk = (lenkeTittel: string, erLenkeFavoritt: boolean) => {
        const nyFavorittliste = erLenkeFavoritt
            ? favorittLenker.filter((favoritt) => favoritt !== lenkeTittel)
            : [...favorittLenker, lenkeTittel];
        settFavorittLenker(nyFavorittliste);
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.driftsportalfavoritt,
            lenkeTittel,
            !erLenkeFavoritt ? "På" : "Av",
        );
    };

    return (
        <ErrorBoundary info={`side: Driftsportalen`}>
            <AuthenticationWrapper>
                <DriftsportalHeader>
                    <ScrollToLenker lenker={lenker} />
                </DriftsportalHeader>
                <Innhold>
                    <Snarveier>
                        <InterntLenkeKort
                            lenke={sideInfo.produksjonskart.href}
                            tekst={sideInfo.produksjonskart.beskrivelse}
                            ikonPath={sideInfo.produksjonskart.ikonUrl}
                        />
                        <InterntLenkeKort
                            lenke={sideInfo.øktdetaljer.href}
                            tekst={sideInfo.øktdetaljer.beskrivelse}
                            ikonPath={sideInfo.øktdetaljer.ikonUrl}
                        />
                        <InterntLenkeKort
                            lenke={sideInfo.webkamera.href}
                            tekst={sideInfo.webkamera.beskrivelse}
                            ikonPath={sideInfo.webkamera.ikonUrl}
                        />
                        <InterntLenkeKort
                            lenke={sideInfo.friksjonsdashboard.href}
                            tekst={sideInfo.friksjonsdashboard.beskrivelse}
                            ikonPath={sideInfo.friksjonsdashboard.ikonUrl}
                        />
                    </Snarveier>{" "}
                    {favorittLenker.length > 0 && (
                        <>
                            <Heading as="h2" styleLevel={"2"}>
                                Favoritter
                            </Heading>
                            <Lenkeliste
                                ref={favorittLenkerRef as UlRef}
                                aria-label="Nyttige lenker"
                            >
                                {portalLenker
                                    .sort((lenke1, lenke2) =>
                                        lenke1.tittel < lenke2.tittel ? -1 : 1,
                                    )
                                    .filter((lenke) => favorittLenker.includes(lenke.tittel))
                                    .map((lenke, index) => (
                                        <EksterntLenkeKort
                                            tittel={lenke.tittel}
                                            lenke={lenke.lenke}
                                            key={index}
                                            ingress={lenke.tekst}
                                            erFavoritt={favorittLenker.includes(lenke.tittel)}
                                            håndterFavorittKlikket={håndterFavorittLenkeKlikk}
                                            dato={lenke.dato}
                                        />
                                    ))}
                            </Lenkeliste>
                            <StyledHr />
                            <Heading as="h2" styleLevel={"2"}>
                                Alle lenker
                            </Heading>
                        </>
                    )}
                    <Lenkeliste ref={lenkerRef as UlRef} aria-label="Nyttige lenker">
                        {portalLenker
                            .sort((lenke1, lenke2) => (lenke1.tittel < lenke2.tittel ? -1 : 1))
                            .map((lenke, index) => (
                                <EksterntLenkeKort
                                    tittel={lenke.tittel}
                                    lenke={lenke.lenke}
                                    key={index}
                                    ingress={lenke.tekst}
                                    erFavoritt={favorittLenker.includes(lenke.tittel)}
                                    håndterFavorittKlikket={håndterFavorittLenkeKlikk}
                                    dato={lenke.dato}
                                />
                            ))}
                    </Lenkeliste>
                    <Panel tittel=" Tips og triks" ref={tipsOgTriksRef}>
                        <Karusell>
                            {tipsOgTriks.map((tips, index) => (
                                <TipsOgTriks
                                    tittel={tips.tittel}
                                    tekst={tips.tekst}
                                    lenker={tips.lenker}
                                    bilder={tips.bilder}
                                    key={index}
                                />
                            ))}
                        </Karusell>
                    </Panel>
                    <OmKos ref={omKosRef} />
                    <p style={{ opacity: "0" }}>works</p>
                </Innhold>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Innhold = styled.main`
    margin: auto;
    display: flex;
    flex-direction: column;
    gap: 2rem;
    max-width: 100rem;
    padding: 0 2rem;

    @media (max-width: ${breakpointNettbrett}) {
        padding: 0 1rem;
    }
`;

const Lenkeliste = styled.ul`
    display: flex;
    flex-wrap: wrap;
    list-style: none;
    padding: 0;
    gap: 1.5rem;
    column-gap: 1.5rem;
`;

const Snarveier = styled.ul`
    list-style: none;
    display: flex;
    gap: 1.5rem;
    padding: 0;
    flex-wrap: wrap;
    flex-direction: row;
`;

const StyledHr = styled.hr`
    margin-bottom: 64px;
    width: 90%;
`;
