import React, { useContext } from "react";
import { InformasjonPopup } from "../InformasjonPopup";
import styled from "styled-components";
import { KameraPanel } from "./KameraPanel";
import { Kamera } from "../../../api/useHentVærstasjoner";
import { erIDag, erSammeTime } from "../../../utils/tid";
import { Værpanel } from "./Værpanel";
import { useAtomValue } from "jotai";
import { tidspunktAtom } from "../../../api/context/kontraktAtoms";
import { useHentVærdata, værdataDtoTilVærdata } from "../../../api/useHentVærdata";
import { Spinner } from "../../../components/fellesKomponenter/spinner/Spinner";

export interface KameraPopupProps {
    kamera: Kamera;
}

export const KameraPopup = ({ kamera }: KameraPopupProps) => {
    const tidspunkt = useAtomValue(tidspunktAtom);
    const historiskVærdata = useHentVærdata(
        tidspunkt,
        kamera.målestasjonId,
        !erSammeTime(tidspunkt) && kamera.målestasjonId !== undefined,
    );
    return (
        <InformasjonPopup
            tittel={
                kamera.vegNummer && kamera.beskrivelse
                    ? `${kamera.vegNummer} ${kamera.beskrivelse}`
                    : "Vegkamera"
            }
            undertekst={kamera.retning}
            detaljWidth={696}
            ikonPath="/ikon/kart/varkamera-gruppe.svg"
            ikonBorder={2}
        >
            <PopupInnhold>
                {erSammeTime(tidspunkt) ? (
                    <KameraPanel kamera={kamera} />
                ) : historiskVærdata !== undefined || !kamera.målestasjonId ? (
                    <KameraPanel
                        kamera={kamera}
                        historiskVærdata={værdataDtoTilVærdata(historiskVærdata?.data ?? [])}
                    />
                ) : (
                    <Spinner />
                )}
                {erIDag(tidspunkt) && kamera.værvaselYr && (
                    <Værpanel værvarsel={kamera.værvaselYr} />
                )}
            </PopupInnhold>
        </InformasjonPopup>
    );
};

const PopupInnhold = styled.div`
    padding: 16px;
    margin: 0;
`;
