import React from "react";
import { Kamera } from "../../../api/useHentVærstasjoner";
import dayjs from "dayjs";
import { tilNorskTimestamp } from "../../../utils/tid";
import { Værdata } from "../../../api/useHentVærdata";

interface VærpanelPanelProps {
    værdata: Værdata | undefined;
}

export const VærtabellPanel = ({ værdata }: VærpanelPanelProps) => {
    if (!værdata) return <div>Fant ingen værdata</div>;
    return (
        <div>
            <table>
                <tbody>
                    <tr>
                        <td>Måletidspunkt:</td>
                        <td>
                            {værdata.værtidspunkt
                                ? tilNorskTimestamp(dayjs(værdata.værtidspunkt))
                                : "-"}
                        </td>
                    </tr>
                    <tr>
                        <td>Lufttemp</td>
                        <td>{værdata.temperatur ? `${værdata.temperatur} C` : "-"}</td>
                    </tr>
                    <tr>
                        <td>Relativ fukt</td>
                        <td>{værdata.luftfuktighet ? `${værdata.luftfuktighet} %` : "-"}</td>
                    </tr>
                    <tr>
                        <td>Duggpunkt</td>
                        <td>
                            {værdata.duggpunktTemperatur ? `${værdata.duggpunktTemperatur} C` : "-"}
                        </td>
                    </tr>
                    <tr>
                        <td>Vegbanetemp</td>
                        <td>
                            {værdata.vegbanetemperatur ? `${værdata.vegbanetemperatur} C` : "-"}
                        </td>
                    </tr>
                    <tr>
                        <td>Nedbørsintensitet</td>
                        <td>{værdata.nedbør ? `${værdata.nedbør} mm/t` : "-"}</td>
                    </tr>
                    <tr>
                        <td>Vind hastighet</td>
                        <td>{værdata.vindHastighet ? `${værdata.vindHastighet} m/s` : "-"}</td>
                    </tr>
                    <tr>
                        <td>Vind retning</td>
                        <td>{værdata.vindRetning ? `${værdata.vindRetning} grader` : "-"}</td>
                    </tr>
                    <tr>
                        <td>Friksjon</td>
                        <td>{værdata.friksjon ? `${værdata.friksjon}` : "-"}</td>
                    </tr>
                    <tr>
                        <td>Sikt</td>
                        <td>{værdata.sikt ? `${værdata.sikt} m` : "-"}</td>
                    </tr>
                </tbody>
            </table>
        </div>
    );
};
