import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";
import { MaterialKategori, MaterialType } from "../../kartSide/types/materiale";
import { MaterialOgAktivitetsNavn } from "../../api/context/ProduksjonsfilterAtoms";
import {
    hentGjennomsnittsverdierForProduksjonsdetaljer,
    MetadataGjennomsnittsType,
} from "./metadataUtils";

describe("MetadataUtils", () => {
    it("skal regne ut gjennomsnittsverdier for produksjonsdetaljer", () => {
        const forventetSnittVerdier: MetadataGjennomsnittsType[] = [
            {
                tittel: "Brøyting",
                snitthastighetAvg: 53,
                snittDosering: undefined,
                snittSprederbredde: undefined,
                antallMålinger: 3,
                doseringsEnhet: undefined,
            },
            {
                tittel: "Strøing med fastsand",
                snitthastighetAvg: 40,
                snittDosering: 34,
                snittSprederbredde: 33,
                antallMålinger: 2,
                doseringsEnhet: "g/m²",
            },
            {
                tittel: "Brøyting og strøing med tørrsalt",
                snitthastighetAvg: 50,
                snittDosering: 35,
                snittSprederbredde: 34,
                antallMålinger: 2,
                doseringsEnhet: "g/m²",
            },
            {
                tittel: "Ingen produksjon",
                snitthastighetAvg: 52,
                snittDosering: undefined,
                snittSprederbredde: undefined,
                antallMålinger: 1,
                doseringsEnhet: undefined,
            },
        ];

        expect(hentGjennomsnittsverdierForProduksjonsdetaljer(produksjonsdetaljer)).toEqual(
            forventetSnittVerdier,
        );
    });
});

const produksjonsdetaljer: Produksjonsdetaljer[] = [
    {
        produksjonsdataRestRec: [0],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:17:05Z",
        hastighetKmHAvg: 48.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D1 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [1],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:18:06Z",
        hastighetKmHAvg: 61.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D2 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [2],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:19:07Z",
        hastighetKmHAvg: 49.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D3 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [3],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:20:08Z",
        hastighetKmHAvg: 40.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: false,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Fastsand,
            kategori: MaterialKategori.Sand,
            navn: MaterialOgAktivitetsNavn.Fastsand,
        },
        sprederbredde: 30,
        dosering: 30,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D3 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [4],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:21:09Z",
        hastighetKmHAvg: 40.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: false,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Fastsand,
            kategori: MaterialKategori.Sand,
            navn: MaterialOgAktivitetsNavn.Fastsand,
        },
        sprederbredde: 36,
        dosering: 38,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D4 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [5],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:22:10Z",
        hastighetKmHAvg: 50.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Tørrsalt,
            kategori: MaterialKategori.Salt,
            navn: MaterialOgAktivitetsNavn.Tørrsalt,
        },
        sprederbredde: 36,
        dosering: 38,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D5 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [6],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:26:15Z",
        hastighetKmHAvg: 50.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Tørrsalt,
            kategori: MaterialKategori.Salt,
            navn: MaterialOgAktivitetsNavn.Tørrsalt,
        },
        sprederbredde: 32,
        dosering: 31,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D6 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [7],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:27:16Z",
        hastighetKmHAvg: 52.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: false,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D7 m1784",
        rodeId: ["zi_4283"],
    },
];
